@@ -10,7 +10,7 @@ class AbstractInterface(ABC):
     2. setup_view() - where all the UI components are created and
                       set to `self.view`
 
-    * Subclasses have logging support via `self.log_message` and
+    * Subclasses have logging support via `self.log` and
       logs can be viewed in `self.logs`
     * Some subclasses may define a custom `__init__`. When they do,
       it's usually a good idea to call `super().__init__` at the end
@@ -40,9 +40,9 @@ class AbstractInterface(ABC):
 
     def setup_logging(self):
         self.logs = widgets.Output()
-        self.log_message("Logging initialised")
+        self.log("Logging initialised")
 
-    def log_message(self, message):
+    def log(self, message):
         with self.logs:
             print(message)
 
